summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCarsten Haitzler (Rasterman) <raster@rasterman.com>2017-08-02 18:45:44 +0900
committerCarsten Haitzler (Rasterman) <raster@rasterman.com>2017-08-02 18:48:06 +0900
commitbdadc30691eb0b48233751b2211f953d56ad8d58 (patch)
treeeceeccc6a75fdbc69439338e49f44c259795df66
parented947fad81f6409f41b7d5a903b6d4b21ac34479 (diff)
downloadefl-bdadc30691eb0b48233751b2211f953d56ad8d58.tar.gz
epp - fix buffer size for possibly bigger int snpritnfs
8 bytes wasn't enough for the full int range. use 12 and we're good. removes warning for sure @fix
-rw-r--r--src/bin/edje/epp/cpplib.c2
1 files changed, 1 insertions, 1 deletions
diff --git a/src/bin/edje/epp/cpplib.c b/src/bin/edje/epp/cpplib.c
index 2f84c343c3..48c19694b2 100644
--- a/src/bin/edje/epp/cpplib.c
+++ b/src/bin/edje/epp/cpplib.c
@@ -2347,7 +2347,7 @@ special_symbol(HASHNODE * hp, cpp_reader * pfile)
if (ip->fname)
true_indepth++;
- bufx = (char *)alloca(8); /* Eight bytes ought to be more than enough */
+ bufx = (char *)alloca(12); // 12 bytes - more than enough
sprintf(bufx, "%d", true_indepth - 1);
buf = bufx;
break;